Module client

Module client 

REST API Client Orchestration Orchestrator for the sqlmapapi.py subprocess and its RESTful interface.

Structs

SqlmapEngine
Manages the sqlmapapi lifecycle and provides access to its REST API.
SqlmapTask
An RAII tracked execution task. Ensures the Daemon memory is purged cleanly on Drop.