pub struct SqlmapEngine { /* private fields */ }Expand description
Manages the sqlmapapi lifecycle and provides access to its REST API.
Implementations
Sourceimpl SqlmapEngine
impl SqlmapEngine
Sourcepub async fn new(
port: u16,
spawn_local: bool,
binary_path: Option<&str>,
) -> Result<Self, SqlmapError>
pub async fn new( port: u16, spawn_local: bool, binary_path: Option<&str>, ) -> Result<Self, SqlmapError>
Launches a local sqlmapapi daemon on a specific port, or connects to an existing remote one.
Sourcepub async fn create_task(
&self,
options: &SqlmapOptions,
) -> Result<SqlmapTask<'_>, SqlmapError>
pub async fn create_task( &self, options: &SqlmapOptions, ) -> Result<SqlmapTask<'_>, SqlmapError>
Creates and configures a new scanning task, returning an RAII wrapper.
Sourceimpl SqlmapEngine
impl SqlmapEngine
Sourcepub fn is_available() -> bool
pub fn is_available() -> bool
Check if sqlmapapi is available on this system.